@@ -9,6 +9,7 @@
 #ifdef Q_WS_MAEMO_5
     #include "backends/mafw/mafwrendereradapter.h"
     #include "backends/mafw/mafwplaylistadapter.h"
+    #include "backends/mafw/mafwsourceadapter.h"
 #endif
 
 #define SYSTEM_PLAYER_SONG_TITLE "title"
@@ -46,6 +47,8 @@ private:
 #ifdef Q_WS_MAEMO_5
     MafwRendererAdapter *m_renderer;
     MafwPlaylistAdapter* m_Playlist;
+    MafwSourceAdapter* m_Tracker;
+
     int m_mafwState;
 #endif
     SystemPlayer::PlaybackState m_state;
@@ -58,6 +61,7 @@ private slots:
     void mafwMediaChanged(int index, char* objectId);
     void onGotMafwState(MafwPlaylist*, uint, MafwPlayState, const char*, QString);
     void onGotMafwMetadata(GHashTable*,QString,QString);
+    void onGotMafwTrackerMetadata(QString,GHashTable*,QString);
     void onPlaylistChanged();
     void onGotPosition(int, QString);
 #endif
