@@ -260,6 +260,10 @@ LsWidget* LockScreen::createWidget(QString type, QString name)
         return new LsProfile(name);
     else if (type == "TextCommand")
         return new LsTextCommand(name);
+    else if (type == "Alarm")
+        return new LsAlarm(name);
+    else if (type == "Calendar")
+        return new LsCalendar(name);
     return NULL;
 }
 
@@ -428,6 +432,7 @@ void LockScreen::startUpdate()
         LsWidget* w = dynamic_cast<LsWidget*>(item);
         if (w != NULL)
             w->startUpdate();
+            //QtConcurrent::run(w, &LsWidget::startUpdate);
     }
 }
 
