@@ -39,6 +39,8 @@ void LsDateTime::applySettings()
     m_TimeFormat = getSetting("TimeFormat", "hh:mm").toString();
     if (m_TimeFormat.contains("s"))
         m_Timer.setInterval(500);
+    else if (m_TimeFormat.count('d') >= 5)
+        m_Timer.setInterval(500);
     else
         m_Timer.setInterval(2000);
 
@@ -85,7 +87,21 @@ void LsDateTime::paint(QPainter *painter, const QStyleOptionGraphicsItem* option
 void LsDateTime::timerSlot()
 {
     QDateTime now = QDateTime::currentDateTime();
-    QString time = QLocale().toString(now, m_TimeFormat);
+    QString time;
+    if (m_TimeFormat.contains("d")) {
+        int msecs = QTime().msecsTo(now.time());
+        float dime = msecs / 86400000.0;
+        for(QString::const_iterator c = m_TimeFormat.constBegin(); c != m_TimeFormat.constEnd(); ++c) {
+            if (*c == 'd'){
+                dime *= 10;
+                time.push_back("0123456789"[int(dime)]);
+                dime -= int(dime);
+            } else{
+                time.push_back(*c);
+            }
+        }
+    } else
+        time = QLocale().toString(now, m_TimeFormat);
     QString date = QLocale().toString(now, m_DateFormat);
     if (time != m_TimeString || date != m_DateString){
         m_TimeString = time;
