@@ -18,6 +18,7 @@
 #ifndef LSTEXTCOMMAND_H
 #define LSTEXTCOMMAND_H
 #include <QTimer>
+#include <QDateTime>
 #include <QProcess>
 #include "lstext.h"
 
@@ -33,6 +34,7 @@ public:
 
 private:
     QTimer* m_Timer;
+    QDateTime m_LastUpdate;
     QProcess* m_Process;
     QString m_Command;
     int m_UpdateInterval;
